{ config, lib, pkgs, modulesPath, inputs, ... }:

{
  imports = [
    ./hardware.nix
    ./secrets.nix
    
    ../../common/system.nix
    ../../common/users.nix
    ../../common/services.nix
    ../../host-secrets.nix
  ];

  # Enable modules
  modules.caddy.enable = true;
  modules.garage.enable = true;

  modules.caddy = {
    email = "ana@nekomimi.pet";
    reverseProxies = {
      "s3.nkp.pet" = ["valefar:3900" "morax:3900"];
    };
  };

  system.stateVersion = "25.05";

  nixpkgs.hostPlatform = lib.mkDefault "aarch64-linux";
  hardware.enableRedistributableFirmware = true;
  hardware.enableAllHardware = lib.mkForce false; #https://github.com/NixOS/nixpkgs/issues/154163#issuecomment-2868994145

  networking = {
    hostName = "morax";
    hostId = "2631a44a";
    firewall.enable = false;
    defaultGateway = {
      address = "10.0.0.1";
      interface = "eth0";
    };
    nameservers = [ "1.1.1.1" ];
    interfaces.eth0 = {
      ipv4.addresses = [{
        address = "10.0.0.210";
        prefixLength = 24;
      }];
    };
  };

  environment.systemPackages = with pkgs; [
    inputs.agenix.packages.aarch64-linux.default
  ];

  virtualisation.docker = {
    enable = true;
    enableOnBoot = true;
  };
}